@@ -20,8 +20,11 @@ import grp
 import pwd
 import pecan
 import sys
+import signal
 import os
 from libra.admin_api.stats.scheduler import Stats
+from libra.admin_api.device_pool.manage_pool import Pool
+from libra.admin_api.expunge.expunge import ExpungeScheduler
 from libra.admin_api import config as api_config
 from libra.admin_api import model
 from libra.admin_api.stats.drivers.base import known_drivers
@@ -48,7 +51,11 @@ def setup_app(pecan_config, args):
         'server': args.gearman,
         'ssl_key': args.gearman_ssl_key,
         'ssl_cert': args.gearman_ssl_cert,
-        'ssl_ca': args.gearman_ssl_ca
+        'ssl_ca': args.gearman_ssl_ca,
+        'keepalive': args.gearman_keepalive,
+        'keepcnt': args.gearman_keepcnt,
+        'keepidle': args.gearman_keepidle,
+        'keepintvl': args.gearman_keepintvl
     }
     config['conffile'] = args.config
     if args.debug:
@@ -72,6 +79,33 @@ def setup_app(pecan_config, args):
     return app
 
 
+class MaintThreads(object):
+    def __init__(self, logger, args, drivers):
+        self.classes = []
+        self.logger = logger
+        self.args = args
+        self.drivers = drivers
+        signal.signal(signal.SIGINT, self.exit_handler)
+        signal.signal(signal.SIGTERM, self.exit_handler)
+        self.run_threads()
+
+    def run_threads(self):
+        stats = Stats(self.logger, self.args, self.drivers)
+        pool = Pool(self.logger, self.args)
+        expunge = ExpungeScheduler(self.logger, self.args)
+        self.classes.append(stats)
+        self.classes.append(pool)
+        self.classes.append(expunge)
+
+    def exit_handler(self, signum, frame):
+        signal.signal(signal.SIGINT, signal.SIG_IGN)
+        signal.signal(signal.SIGTERM, signal.SIG_IGN)
+        for function in self.classes:
+            function.shutdown()
+        self.logger.info("Safely shutting down")
+        sys.exit()
+
+
 class LogStdout(object):
     def __init__(self, logger):
         self.logger = logger.info
@@ -106,6 +140,22 @@ def main():
         '--gearman', action='append', metavar='HOST:PORT', default=[],
         help='Gearman job servers'
     )
+    options.parser.add_argument(
+        '--gearman_keepalive', action="store_true",
+        help='use KEEPALIVE to Gearman server'
+    )
+    options.parser.add_argument(
+        '--gearman_keepcnt', type=int, metavar='COUNT',
+        help='max keepalive probes to send before killing connection'
+    )
+    options.parser.add_argument(
+        '--gearman_keepidle', type=int, metavar='SECONDS',
+        help='seconds of idle time before sending keepalive probes'
+    )
+    options.parser.add_argument(
+        '--gearman_keepintvl', type=int, metavar='SECONDS',
+        help='seconds between TCP keepalive probes'
+    )
     options.parser.add_argument(
         '--gearman_ssl_ca', metavar='FILE',
         help='Gearman SSL certificate authority'
@@ -131,6 +181,14 @@ def main():
         '--stats_poll_timeout_retry', type=int, default=30,
         help='gearman timeout value for retry ping request (in seconds)'
     )
+    options.parser.add_argument(
+        '--stats_offline_ping_limit', type=int, default=10,
+        help='Number of failed pings to an OFFLINE device before deleting it'
+    )
+    options.parser.add_argument(
+        '--stats_device_error_limit', type=int, default=5,
+        help='Max number of simultaneous device failures to allow recovery on'
+    )
     options.parser.add_argument(
         '--number_of_servers', type=int, default=1,
         help='number of Admin API servers, used to calculate which Admin API '
@@ -160,6 +218,18 @@ def main():
         '--datadog_env', default='unknown',
         help='Server enironment'
     )
+    options.parser.add_argument(
+        '--node_pool_size', default=10, type=int,
+        help='Number of hot spare devices to keep in the pool'
+    )
+    options.parser.add_argument(
+        '--vip_pool_size', default=10, type=int,
+        help='Number of hot spare vips to keep in the pool'
+    )
+    options.parser.add_argument(
+        '--expire_days', default=0,
+        help='Number of days until deleted load balancers are expired'
+    )
 
     args = options.run()
 
@@ -218,7 +288,7 @@ def main():
         drivers.append(importutils.import_class(
             known_drivers[driver]
         ))
-    Stats(logger, args, drivers)
+    MaintThreads(logger, args, drivers)
     sys.stderr = LogStdout(logger)
     # TODO: set ca_certs and cert_reqs=CERT_REQUIRED
     ssl_sock = eventlet.wrap_ssl(
