@@ -28,6 +28,7 @@ from logs import LogsController
 # models
 from libra.common.api.lbaas import LoadBalancer, Device, Node, db_session
 from libra.common.api.lbaas import loadbalancers_devices, Limits, Vip
+from libra.common.api.lbaas import HealthMonitor
 from libra.api.model.validators import LBPut, LBPost, LBResp, LBVipResp
 from libra.api.model.validators import LBRespNode
 from libra.common.api.gearman_client import submit_job, submit_vip_job
@@ -184,6 +185,11 @@ class LoadBalancersController(RestController):
                 raise ClientSideError(
                     'Node {0} is missing a port'.format(node.address)
                 )
+            if node.port < 1 or node.port > 65535:
+                raise ClientSideError(
+                    'Node {0} port number {1} is invalid'
+                    .format(node.address, node.port)
+                )
             try:
                 node.address = ipfilter(node.address, conf.ip_filters)
             except IPOutOfRange:
@@ -237,6 +243,10 @@ class LoadBalancersController(RestController):
                 lb.protocol = 'HTTP'
 
             if body.port:
+                if body.port < 1 or body.port > 65535:
+                    raise ClientSideError(
+                        'Port number {0} is invalid'.format(body.port)
+                    )
                 lb.port = body.port
             else:
                 if lb.protocol == 'HTTP':
@@ -282,6 +292,14 @@ class LoadBalancersController(RestController):
                 ).join(Device.vip).\
                     filter(Vip.id == virtual_id).\
                     first()
+
+                if device.status == 'ERROR':
+                    session.rollback()
+                    raise ClientSideError(
+                        'Cannot add a Load Balancer to a device'
+                        ' in an ERROR state'
+                    )
+
                 old_lb = session.query(
                     LoadBalancer
                 ).join(LoadBalancer.devices).\
@@ -299,8 +317,9 @@ class LoadBalancersController(RestController):
                 old_count = session.query(
                     LoadBalancer
                 ).join(LoadBalancer.devices).\
+                    join(Device.vip).\
                     filter(LoadBalancer.tenantid == tenant_id).\
-                    filter(Device.id == virtual_id).\
+                    filter(vip.id == virtual_id).\
                     filter(LoadBalancer.port == lb.port).\
                     count()
                 if old_count:
@@ -399,10 +418,17 @@ class LoadBalancersController(RestController):
 
             lb.status = 'PENDING_UPDATE'
             device = session.query(
-                Device.id, Device.name
+                Device.id, Device.name, Device.status
             ).join(LoadBalancer.devices).\
                 filter(LoadBalancer.id == self.lbid).\
                 first()
+
+            if device.status == 'ERROR':
+                session.rollback()
+                raise ClientSideError(
+                    'Cannot update a Load Balancer in an ERROR state'
+                )
+
             session.commit()
             submit_job(
                 'UPDATE', device.name, device.id, lb.id
@@ -442,9 +468,20 @@ class LoadBalancersController(RestController):
             ).join(LoadBalancer.devices).\
                 filter(LoadBalancer.id == load_balancer_id).\
                 first()
-            submit_job(
-                'DELETE', device.name, device.id, lb.id
-            )
+            if device is None:
+                # This can happen if a device was manually deleted from the DB
+                lb.status = 'DELETED'
+                session.execute(loadbalancers_devices.delete().where(
+                    loadbalancers_devices.c.loadbalancer == lb.id
+                ))
+                session.query(Node).\
+                    filter(Node.lbid == lb.id).delete()
+                session.query(HealthMonitor).\
+                    filter(HealthMonitor.lbid == lb.id).delete()
+            else:
+                submit_job(
+                    'DELETE', device.name, device.id, lb.id
+                )
             session.commit()
             return None
 
