@@ -48,10 +48,17 @@ class LogsController(RestController):
 
             load_balancer.status = 'PENDING_UPDATE'
             device = session.query(
-                Device.id, Device.name
+                Device.id, Device.name, Device.status
             ).join(LoadBalancer.devices).\
                 filter(LoadBalancer.id == self.lbid).\
                 first()
+
+            if device.status == 'ERROR':
+                session.rollback()
+                raise ClientSideError(
+                    'Load Balancer is currently in an ERROR state'
+                )
+
             session.commit()
             data = {
                 'deviceid': device.id
