@@ -52,6 +52,8 @@ class Node(object):
         self.secgroup = args.nova_secgroup
         self.node_basename = args.node_basename
         self.az = args.nova_az_name
+        self.rm_fip_ignore_500 = args.rm_fip_ignore_500
+
         # Replace '_' with '-' in basename
         if self.node_basename:
             self.node_basename = self.node_basename.replace('_', '-')
@@ -99,17 +101,23 @@ class Node(object):
             )
 
     def vip_remove(self, node_id, vip):
-        """ assign a virtual IP to a Nova instance """
+        """ delete a virtual IP from a Nova instance """
         url = '/servers/{0}/action'.format(node_id)
         body = {
             "removeFloatingIp": {
                 "address": vip
             }
         }
-        resp, body = self.nova.post(url, body=body)
+        try:
+            resp, body = self.nova.post(url, body=body)
+        except exceptions.ClientException as e:
+            if e.code == 500 and self.rm_fip_ignore_500:
+                return
+            raise
+
         if resp.status_code != 202:
             raise Exception(
-                'Response code {0}, message {1} when assigning vip'
+                'Response code {0}, message {1} when removing vip'
                 .format(resp.status_code, body)
             )
 
